@@ -28,19 +28,35 @@ iterT <- iter1 + iter2
 # ------------------------------------------------------------------------------
 
 test_that('tune recipe only', {
-
   set.seed(4400)
   wflow <- workflow() %>% add_recipe(rec_tune_1) %>% add_model(lm_mod)
   pset <- dials::parameters(wflow) %>% update(num_comp = num_comp(c(1, 5)))
   folds <- vfold_cv(mtcars)
+  control <- control_bayes(extract = identity)
+
   res <- tune_bayes(wflow, resamples = folds, param_info = pset,
-                    initial = iter1, iter = iter2)
-  expect_equal(unique(res$id), folds$id)
+                    initial = iter1, iter = iter2, control = control)
   res_est <- collect_metrics(res)
+  res_workflow <- res$.extracts[[1]]$.extracts[[1]]
+
+  # Ensure tunable parameters in recipe are finalized
+  num_comp <- res_workflow$pre$actions$recipe$recipe$steps[[2]]$num_comp
+
+  expect_equal(unique(res$id), folds$id)
   expect_equal(nrow(res_est), iterT * 2)
   expect_equal(sum(res_est$.metric == "rmse"), iterT)
   expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
   expect_equal(res_est$n, rep(10, iterT * 2))
+  expect_false(identical(num_comp, expr(tune())))
+  expect_true(res_workflow$trained)
+
+  expect_error(
+    tune_bayes(wflow, resamples = folds, param_info = pset,
+               initial = iter1, iter = iter2,
+               corr = list(type = "matern", nu = 3/2)),
+    regexp = NA
+  )
 })
 
 # ------------------------------------------------------------------------------
@@ -58,6 +74,39 @@ test_that('tune model only (with recipe)', {
   expect_equal(nrow(res_est), iterT * 2)
   expect_equal(sum(res_est$.metric == "rmse"), iterT)
   expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
+  expect_equal(res_est$n, rep(10, iterT * 2))
+})
+
+# ------------------------------------------------------------------------------
+
+test_that('tune model only (with variables)', {
+  set.seed(4400)
+
+  wflow <- workflow() %>%
+    add_variables(mpg, everything()) %>%
+    add_model(svm_mod)
+
+  pset <- dials::parameters(wflow)
+
+  folds <- vfold_cv(mtcars)
+
+  res <- tune_bayes(
+    wflow,
+    resamples = folds,
+    param_info = pset,
+    initial = iter1,
+    iter = iter2
+  )
+
+  expect_equal(unique(res$id), folds$id)
+
+  res_est <- collect_metrics(res)
+
+  expect_equal(nrow(res_est), iterT * 2)
+  expect_equal(sum(res_est$.metric == "rmse"), iterT)
+  expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
   expect_equal(res_est$n, rep(10, iterT * 2))
 })
 
@@ -82,6 +131,7 @@ test_that('tune model only (with recipe, multi-predict)', {
   expect_equal(nrow(res_est), iterT * 2)
   expect_equal(sum(res_est$.metric == "rmse"), iterT)
   expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
   expect_equal(res_est$n, rep(10, iterT * 2))
 })
 
@@ -104,6 +154,7 @@ test_that('tune model and recipe', {
   expect_equal(nrow(res_est), iterT * 2)
   expect_equal(sum(res_est$.metric == "rmse"), iterT)
   expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
   expect_equal(res_est$n, rep(10, iterT * 2))
 })
 
@@ -125,6 +176,7 @@ test_that('tune model and recipe (multi-predict)', {
   expect_equal(nrow(res_est), iterT * 2)
   expect_equal(sum(res_est$.metric == "rmse"), iterT)
   expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
   expect_equal(res_est$n, rep(10, iterT * 2))
 })
 
@@ -162,6 +214,7 @@ test_that('tune recipe and model, which has_unknowns', {
   expect_equal(nrow(res_est), iterT * 2)
   expect_equal(sum(res_est$.metric == "rmse"), iterT)
   expect_equal(sum(res_est$.metric == "rsq"), iterT)
+  expect_equal(dplyr::n_distinct(res_est$.config), iterT)
   expect_equal(res_est$n, rep(10, iterT * 2))
 })
 
@@ -301,52 +354,32 @@ test_that("tune model and recipe - failure in recipe is caught elegantly", {
 })
 
 test_that("argument order gives warning for recipes", {
-  expect_warning(
+  expect_error(
     tune_bayes(rec_tune_1, model = lm_mod, resamples = vfold_cv(mtcars, v = 2),
                param_info = dials::parameters(rec_tune_1),
                iter = iter1, initial = iter2),
-    "is deprecated as of lifecycle"
+    "should be either a model or workflow"
   )
 })
 
 test_that("argument order gives warning for formula", {
-  expect_warning(
+  expect_error(
     tune_bayes(mpg ~ ., svm_mod, resamples = vfold_cv(mtcars, v = 2),
                param_info = dials::parameters(svm_mod),
                initial = iter1, iter = iter2),
-    "is deprecated as of lifecycle"
+    "should be either a model or workflow"
   )
 })
 
-test_that("ellipses with tune_bayes", {
-
-  # This test currently fails, because tune_bayes() actually passes the ... to
-  # fit_gp(). This behavior seems to be undocumented.
-
-  skip_if("..." %in% names(formals(fit_gp)))
-
-  set.seed(4400)
-  wflow <- workflow() %>% add_recipe(rec_tune_1) %>% add_model(lm_mod)
-  pset <- dials::parameters(wflow)
-  folds <- vfold_cv(mtcars)
-  expect_warning(
-    tune_bayes(wflow, resamples = folds, param_info = pset,
-               initial = iter1, iter = iter2, something = "wrong"),
-    "The `...` are not used in this function but one or more objects"
-  )
-})
-
-
-
-
-test_that("retain extra attributes", {
+test_that("retain extra attributes and saved GP candidates", {
 
   set.seed(4400)
   wflow <- workflow() %>% add_recipe(rec_tune_1) %>% add_model(lm_mod)
   pset <- dials::parameters(wflow) %>% update(num_comp = num_comp(c(1, 5)))
   folds <- vfold_cv(mtcars)
+  ctrl <- control_bayes(save_gp_scoring = TRUE)
   res <- tune_bayes(wflow, resamples = folds, param_info = pset,
-                    initial = iter1, iter = iter2)
+                    initial = iter1, iter = iter2, control = ctrl)
 
   att <- attributes(res)
   att_names <- names(att)
@@ -359,6 +392,10 @@ test_that("retain extra attributes", {
   expect_true(inherits(att$parameters, "parameters"))
   expect_true(inherits(att$metrics, "metric_set"))
 
+  files <- list.files(path = tempdir(), pattern = "^gp_candidates")
+  expect_true(length(files) == iter2)
+
+
   expect_message(
     res2 <- tune_bayes(wflow, resamples = folds, param_info = pset,
                        initial = iter1, iter = iter2,
@@ -370,3 +407,50 @@ test_that("retain extra attributes", {
 
 
 })
+
+# ------------------------------------------------------------------------------
+
+test_that('too few starting values', {
+  options(width = 120)
+  # TODO Add specific checks with racing objects once finetune is released
+  expect_silent(tune:::check_bayes_initial_size(5, 30, FALSE))
+
+  expect_message(
+    tune:::check_bayes_initial_size(5, 3, FALSE),
+    "5 tuning parameters and 3 grid points were"
+  )
+
+  expect_message(
+    tune:::check_bayes_initial_size(5, 3, TRUE),
+    "numerical issues"
+  )
+  expect_message(
+    tune:::check_bayes_initial_size(5, 3, TRUE),
+    "With racing"
+  )
+
+  expect_error(
+    tune:::check_bayes_initial_size(5, 1, FALSE),
+    "requires 2+"
+  )
+
+  expect_error(
+    tune:::check_bayes_initial_size(5, 1, TRUE),
+    "requires 2+"
+  )
+  expect_error(
+    tune:::check_bayes_initial_size(5, 1, TRUE),
+    "With racing"
+  )
+
+  expect_error(
+    tune:::check_bayes_initial_size(5, 1, FALSE),
+    "a single grid point was"
+  )
+  expect_error(
+    tune:::check_bayes_initial_size(1, 1, FALSE),
+    "is one tuning parameter"
+  )
+
+})
+
