@@ -22,33 +22,76 @@ svm_mod <- svm_rbf(mode = "regression", cost = tune()) %>% set_engine("kernlab")
 # ------------------------------------------------------------------------------
 
 test_that('tune recipe only', {
-
   set.seed(4400)
   wflow <- workflow() %>% add_recipe(rec_tune_1) %>% add_model(lm_mod)
   pset <- dials::parameters(wflow) %>% update(num_comp = num_comp(c(1, 3)))
   grid <- grid_regular(pset, levels = 3)
   folds <- vfold_cv(mtcars)
-  res <- tune_grid(wflow, resamples = folds, grid = grid)
-  expect_equal(res$id, folds$id)
+  control <- control_grid(extract = identity)
+
+  res <- tune_grid(wflow, resamples = folds, grid = grid, control = control)
   res_est <- collect_metrics(res)
+  res_workflow <- res$.extracts[[1]]$.extracts[[1]]
+
+  # Ensure tunable parameters in recipe are finalized
+  num_comp <- res_workflow$pre$actions$recipe$recipe$steps[[2]]$num_comp
+
+  expect_equal(res$id, folds$id)
   expect_equal(nrow(res_est), nrow(grid) * 2)
   expect_equal(sum(res_est$.metric == "rmse"), nrow(grid))
   expect_equal(sum(res_est$.metric == "rsq"), nrow(grid))
   expect_equal(res_est$n, rep(10, nrow(grid) * 2))
+  expect_false(identical(num_comp, expr(tune())))
+  expect_true(res_workflow$trained)
 })
 
 # ------------------------------------------------------------------------------
 
 test_that('tune model only (with recipe)', {
-
   set.seed(4400)
   wflow <- workflow() %>% add_recipe(rec_no_tune_1) %>% add_model(svm_mod)
   pset <- dials::parameters(wflow)
   grid <- grid_regular(pset, levels = 3)
   folds <- vfold_cv(mtcars)
-  res <- tune_grid(wflow, resamples = folds, grid = grid)
-  expect_equal(res$id, folds$id)
+  control <- control_grid(extract = identity)
+
+  res <- tune_grid(wflow, resamples = folds, grid = grid, control = control)
   res_est <- collect_metrics(res)
+  res_workflow <- res$.extracts[[1]]$.extracts[[1]]
+
+  # Ensure tunable parameters in spec are finalized
+  cost_quo <- res_workflow$fit$fit$spec$args$cost
+  cost <- quo_get_expr(cost_quo)
+
+  expect_equal(res$id, folds$id)
+  expect_equal(nrow(res_est), nrow(grid) * 2)
+  expect_equal(sum(res_est$.metric == "rmse"), nrow(grid))
+  expect_equal(sum(res_est$.metric == "rsq"), nrow(grid))
+  expect_equal(res_est$n, rep(10, nrow(grid) * 2))
+  expect_false(identical(cost, expr(tune())))
+  expect_true(res_workflow$trained)
+})
+
+# ------------------------------------------------------------------------------
+
+test_that('tune model only (with variables)', {
+  set.seed(4400)
+
+  wflow <- workflow() %>%
+    add_variables(mpg, everything()) %>%
+    add_model(svm_mod)
+
+  pset <- dials::parameters(wflow)
+  grid <- grid_regular(pset, levels = 3)
+
+  folds <- vfold_cv(mtcars)
+
+  res <- tune_grid(wflow, resamples = folds, grid = grid)
+
+  expect_equal(res$id, folds$id)
+
+  res_est <- collect_metrics(res)
+
   expect_equal(nrow(res_est), nrow(grid) * 2)
   expect_equal(sum(res_est$.metric == "rmse"), nrow(grid))
   expect_equal(sum(res_est$.metric == "rsq"), nrow(grid))
@@ -80,23 +123,36 @@ test_that('tune model only (with recipe, multi-predict)', {
 # ------------------------------------------------------------------------------
 
 test_that('tune model and recipe', {
-
   set.seed(4400)
   wflow <- workflow() %>% add_recipe(rec_tune_1) %>% add_model(svm_mod)
   pset <- dials::parameters(wflow) %>% update(num_comp = num_comp(c(1, 3)))
   grid <- grid_regular(pset, levels = 3)
   folds <- vfold_cv(mtcars)
-  res <- tune_grid(wflow, resamples = folds, grid = grid)
+  control <- control_grid(extract = identity)
+
+  res <- tune_grid(wflow, resamples = folds, grid = grid, control = control)
+  res_est <- collect_metrics(res)
+  res_workflow <- res$.extracts[[1]]$.extracts[[1]]
+
+  # Ensure tunable parameters in spec are finalized
+  cost_quo <- res_workflow$fit$fit$spec$args$cost
+  cost <- quo_get_expr(cost_quo)
+
+  # Ensure tunable parameters in recipe are finalized
+  num_comp <- res_workflow$pre$actions$recipe$recipe$steps[[2]]$num_comp
+
   expect_equal(res$id, folds$id)
   expect_equal(
     colnames(res$.metrics[[1]]),
     c("cost", "num_comp", ".metric", ".estimator", ".estimate", ".config")
   )
-  res_est <- collect_metrics(res)
   expect_equal(nrow(res_est), nrow(grid) * 2)
   expect_equal(sum(res_est$.metric == "rmse"), nrow(grid))
   expect_equal(sum(res_est$.metric == "rsq"), nrow(grid))
   expect_equal(res_est$n, rep(10, nrow(grid) * 2))
+  expect_false(identical(cost, expr(tune())))
+  expect_false(identical(num_comp, expr(tune())))
+  expect_true(res_workflow$trained)
 })
 
 # ------------------------------------------------------------------------------
@@ -119,6 +175,30 @@ test_that('tune model and recipe (multi-predict)', {
 
 # ------------------------------------------------------------------------------
 
+test_that('tune model and recipe (parallel_over = "everything")', {
+  set.seed(4400)
+  wflow <- workflow() %>% add_recipe(rec_tune_1) %>% add_model(svm_mod)
+  pset <- dials::parameters(wflow) %>% update(num_comp = num_comp(c(1, 3)))
+  grid <- grid_regular(pset, levels = 3)
+  folds <- vfold_cv(mtcars)
+  control <- control_grid(extract = identity, parallel_over = "everything")
+
+  res <- tune_grid(wflow, resamples = folds, grid = grid, control = control)
+  res_est <- collect_metrics(res)
+
+  expect_equal(res$id, folds$id)
+  expect_equal(
+    colnames(res$.metrics[[1]]),
+    c("cost", "num_comp", ".metric", ".estimator", ".estimate", ".config")
+  )
+  expect_equal(nrow(res_est), nrow(grid) * 2)
+  expect_equal(sum(res_est$.metric == "rmse"), nrow(grid))
+  expect_equal(sum(res_est$.metric == "rsq"), nrow(grid))
+  expect_equal(res_est$n, rep(10, nrow(grid) * 2))
+})
+
+# ------------------------------------------------------------------------------
+
 test_that("tune recipe only - failure in recipe is caught elegantly", {
 
   set.seed(7898)
@@ -270,17 +350,17 @@ test_that("tune model and recipe - failure in recipe is caught elegantly", {
   )
 })
 
-test_that("argument order gives warning for recipes", {
-  expect_warning(
+test_that("argument order gives errors for recipes", {
+  expect_error(
     tune_grid(rec_tune_1, lm_mod, vfold_cv(mtcars, v = 2)),
-    "is deprecated as of lifecycle"
+    "should be either a model or workflow"
   )
 })
 
-test_that("argument order gives warning for formula", {
-  expect_warning(
+test_that("argument order gives errors for formula", {
+  expect_error(
     tune_grid(mpg ~ ., lm_mod, vfold_cv(mtcars, v = 2)),
-    "is deprecated as of lifecycle"
+    "should be either a model or workflow"
   )
 })
 
