@@ -9,7 +9,7 @@ load(test_path("test_objects.RData"))
 
 test_that('model package lookup', {
   mod_obj <- workflows::pull_workflow_spec(chi_wflow)
-  expect_equal(tune:::mod_pkgs(mod_obj), "glmnet")
+  expect_equal(tune::required_pkgs(mod_obj, FALSE), "glmnet")
 })
 
 
@@ -104,3 +104,8 @@ test_that('accessor functions', {
   attr(mt_knn_bo, "parameters") <- NULL
   expect_equal(.get_tune_parameters(mt_knn_bo), tibble::tibble())
 })
+
+test_that('required package lists', {
+  expect_equal(required_pkgs(lm_model, FALSE), "stats")
+  expect_equal(required_pkgs(chi_wflow, FALSE), "glmnet")
+})
