@@ -1,10 +1,9 @@
-import json
 import os
-import pickle
 import random
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 from uuid import uuid4
 
+import cloudpickle
 import numpy as np
 import pandas as pd
 from fugue import (
@@ -18,8 +17,10 @@ from fugue import (
     WorkflowDataFrame,
     WorkflowDataFrames,
 )
-from triad import ParamDict, assert_or_throw, to_uuid
-
+from triad import FileSystem, ParamDict, assert_or_throw, to_uuid
+from tune._utils import from_base64, to_base64
+from tune.concepts.flow import Trial
+from tune.concepts.space import Space
 from tune.constants import (
     TUNE_DATASET_DF_PREFIX,
     TUNE_DATASET_PARAMS_PREFIX,
@@ -31,8 +32,6 @@ from tune.constants import (
     TUNE_TEMP_PATH,
 )
 from tune.exceptions import TuneCompileError
-from tune.concepts.space import Space
-from tune.concepts.flow import Trial
 
 
 class TuneDataset:
@@ -265,7 +264,9 @@ class TuneDatasetBuilder:
                     fp = os.path.join(p, str(uuid4()) + ".parquet")
                     first = df.peek_dict()
                     keys = [first[x] for x in self.key_schema.names]
-                    df.as_pandas().to_parquet(fp)
+                    fs = FileSystem()
+                    with fs.open(fp, "wb") as handler:
+                        df.as_pandas().to_parquet(handler)
                     return ArrayDataFrame([keys + [fp]], self.output_schema)
 
             return df.transform(SavePartition, params={"path": path, "name": name})
@@ -294,10 +295,10 @@ class TuneDatasetBuilder:
             for a in it:
                 res.append(a)
                 if batch_size == len(res):
-                    yield [pickle.dumps(res)]
+                    yield [cloudpickle.dumps(res)]
                     res = []
             if len(res) > 0:
-                yield [pickle.dumps(res)]
+                yield [cloudpickle.dumps(res)]
 
         return wf.df(
             IterableDataFrame(get_data(), f"{TUNE_DATASET_PARAMS_PREFIX}:binary")
@@ -374,28 +375,26 @@ class StudyResult:
 def _to_trail_row(data: Dict[str, Any], metadata: Dict[str, Any]) -> Dict[str, Any]:
     key_names = sorted(k for k in data.keys() if not k.startswith(TUNE_PREFIX))
     keys = [data[k] for k in key_names]
-    trials: Dict[str, Dict[str, Any]] = {}
-    for param in pickle.loads(data[TUNE_DATASET_PARAMS_PREFIX]):
-        p = ParamDict(sorted(((k, v) for k, v in param.items()), key=lambda x: x[0]))
-        tid = to_uuid(keys, p)
-        trials[tid] = Trial(
-            trial_id=tid, params=p, metadata=metadata, keys=keys
-        ).jsondict
-    data[TUNE_DATASET_TRIALS] = json.dumps(list(trials.values()))
+    trials: Dict[str, Trial] = {}
+    for params in cloudpickle.loads(data[TUNE_DATASET_PARAMS_PREFIX]):
+        tid = to_uuid(keys, params)
+        trials[tid] = Trial(trial_id=tid, params=params, metadata=metadata, keys=keys)
+    data[TUNE_DATASET_TRIALS] = to_base64(list(trials.values()))
     del data[TUNE_DATASET_PARAMS_PREFIX]
     return data
 
 
 def _get_trials_from_row(row: Dict[str, Any], with_dfs: bool = True) -> Iterable[Trial]:
     if not with_dfs:
-        for params in json.loads(row[TUNE_DATASET_TRIALS]):
-            yield Trial.from_jsondict(params)
+        yield from from_base64(row[TUNE_DATASET_TRIALS])
     else:
         dfs: Dict[str, Any] = {}
+        fs = FileSystem()
         for k, v in row.items():
             if k.startswith(TUNE_DATASET_DF_PREFIX):
                 key = k[len(TUNE_DATASET_DF_PREFIX) :]
                 if v is not None:
-                    dfs[key] = pd.read_parquet(v)
-        for params in json.loads(row[TUNE_DATASET_TRIALS]):
-            yield Trial.from_jsondict(params).with_dfs(dfs)
+                    with fs.open(v, "rb") as handler:
+                        dfs[key] = pd.read_parquet(handler)
+        for params in from_base64(row[TUNE_DATASET_TRIALS]):
+            yield params.with_dfs(dfs)
