@@ -1,54 +1,9 @@
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Dict, Optional
+from uuid import uuid4
 
 from tune.concepts.flow.report import TrialReport
 
 
-# TODO: this dispatcher should be generalized in Triad
-_CACHE: List[Tuple[Callable[[Any], bool], Callable[[Any], Any]]] = []
-
-
-def register_logger_parser(
-    matcher: Callable[[Any], bool], func: Callable[[Any], Any]
-) -> None:
-    """Register a parser for :class:`~.MetricLogger`.
-
-    .. admonition:: Experimental
-
-        THis is for internal use only and will change in the future
-
-    :param matcher: a function to decide if the object is a match
-        for the parser
-    :param func: a function that generates a :class:`~.MetricLogger` or
-        a callable that generates a :class:`~.MetricLogger`
-    """
-    _CACHE.append((matcher, func))
-
-
-def parse_logger(obj: Any) -> Any:
-    """On driver side parse an arbitrary object into a
-    :class:`~.MetricLogger` or a callable that generates a
-    :class:`~.MetricLogger`. The correspondent parser must
-    be registered by :func:`.register_logger_parser`.
-
-    .. admonition:: Experimental
-
-        THis is for internal use only and will change in the future
-
-    :param obj: the object.
-    :return: :class:`~.MetricLogger` or a callable that generates a
-    :class:`~.MetricLogger`
-    """
-    from tune import _register  # noqa: F401
-
-    if obj is None or isinstance(obj, MetricLogger) or callable(obj):
-        return obj
-
-    for match, func in _CACHE:
-        if match(obj):
-            return func(obj)
-    raise ValueError(f"{obj} is not a valid logger")
-
-
 def make_logger(obj: Any) -> "MetricLogger":
     """Convert an object to a MetricLogger. This function is usually called on
     the worker side. If ``obj`` is a function, then it can take the context of
@@ -71,12 +26,23 @@ def make_logger(obj: Any) -> "MetricLogger":
 class MetricLogger:
     """Hierarchical metric logger for objectectives"""
 
+    def __init__(self):
+        self._unique_id = str(uuid4())[-5:]
+
+    @property
+    def unique_id(self) -> str:
+        return self._unique_id
+
     def create_child(
-        self, name: Optional[str] = None, is_step: bool = False
+        self,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
+        is_step: bool = False,
     ) -> "MetricLogger":
         """Create a child logger
 
         :param name: the name of the child logger, defaults to None
+        :param description: the long description of the child logger, defaults to None
         :param is_step: whether the child logger is a sub-step, for example for
             an epoch of a deep learning model, it should set to ``True``
 
