@@ -2,13 +2,15 @@
 
 from tune.concepts.space.parameters import (
     Choice,
+    FuncParam,
     Grid,
     NormalRand,
     NormalRandInt,
     Rand,
     RandInt,
     StochasticExpression,
-    _decode_params,
-    _encode_params,
+    TransitionChoice,
+    TuningParametersTemplate,
+    to_template,
 )
-from tune.concepts.space.spaces import HorizontalSpace, Space, VerticalSpace
+from tune.concepts.space.spaces import Space
