@@ -1,16 +1,42 @@
 from datetime import datetime
-from threading import RLock
 from typing import Any, Dict, List
 
 import pandas as pd
+from triad import SerializableRLock
 from triad.utils.convert import to_timedelta
-from tune import Monitor, TrialReport, TrialReportLogger
+from tune import Monitor, TrialReport, TrialReportLogger, parse_monitor
+
+
+@parse_monitor.candidate(
+    lambda obj: isinstance(obj, str) and obj == "hist", priority=0.0
+)
+def _hist(obj: str) -> Monitor:  # pragma: no cover
+    return NotebookSimpleHist()
+
+
+@parse_monitor.candidate(
+    lambda obj: isinstance(obj, str) and obj == "rungs", priority=0.0
+)
+def _rungs(obj: str) -> Monitor:  # pragma: no cover
+    return NotebookSimpleRungs()
+
+
+@parse_monitor.candidate(lambda obj: isinstance(obj, str) and obj == "ts", priority=0.0)
+def _ts(obj: str) -> Monitor:  # pragma: no cover
+    return NotebookSimpleTimeSeries()
+
+
+@parse_monitor.candidate(
+    lambda obj: isinstance(obj, str) and obj == "text", priority=0.0
+)
+def _text(obj: str) -> Monitor:  # pragma: no cover
+    return PrintBest()
 
 
 class PrintBest(Monitor):
     def __init__(self):
         super().__init__()
-        self._lock = RLock()
+        self._lock = SerializableRLock()
         self._bins: Dict[str, "_ReportBin"] = {}
 
     def on_report(self, report: TrialReport) -> None:
@@ -31,7 +57,7 @@ class NotebookSimpleChart(Monitor):
         always_update: bool = False,
     ):
         super().__init__()
-        self._lock = RLock()
+        self._lock = SerializableRLock()
         self._last: Any = None
         self._bins: Dict[str, "_ReportBin"] = {}
         self._interval = to_timedelta(interval)
