@@ -1,8 +1,8 @@
-from threading import RLock
 from typing import Any, Callable, Dict, List, Optional
 
 import optuna
 from optuna.study import Study
+from triad import SerializableRLock
 from tune import (
     Choice,
     NonIterativeObjectiveFunc,
@@ -32,16 +32,19 @@ class OptunaLocalOptimizer(NonIterativeObjectiveLocalOptimizer):
         if template.empty:
             tmp = NonIterativeObjectiveLocalOptimizer()
             return tmp.run(func, trial, logger=logger)
-        lock = RLock()
+        lock = SerializableRLock()
         best_report: List[TrialReport] = []
 
         with make_logger(logger) as p_logger:
-            with p_logger.create_child(name=repr(trial)) as c_logger:
+            with p_logger.create_child(
+                name=trial.trial_id[:5] + "-" + p_logger.unique_id,
+                description=repr(trial),
+            ) as c_logger:
 
                 def obj(otrial: optuna.trial.Trial) -> float:
                     with c_logger.create_child(is_step=True) as s_logger:
                         params = template.fill_dict(_convert(otrial, template))
-                        report = func.run(trial.with_params(params))
+                        report = func.safe_run(trial.with_params(params))
                         with lock:
                             if len(best_report) == 0:
                                 best_report.append(report)
