@@ -1,5 +1,5 @@
 import os
-import pickle
+import cloudpickle
 from tune.api.factory import TUNE_OBJECT_FACTORY
 from typing import Any, Optional, Tuple
 from uuid import uuid4
@@ -46,7 +46,7 @@ class SKObjective(NonIterativeObjectiveFunc):
         return -value
 
     def run(self, trial: Trial) -> TrialReport:
-        params = dict(trial.params)
+        params = dict(trial.params.simple_value)
         if trial.trial_id != self._last_id:
             self._model_type = to_sk_model(params.pop(SPACE_MODEL_NAME))
             self._model_expr = to_sk_model_expr(self._model_type)
@@ -66,7 +66,7 @@ class SKObjective(NonIterativeObjectiveFunc):
         if self._checkpoint_path is not None:
             fp = os.path.join(self._checkpoint_path, str(uuid4()) + ".pkl")
             with FileSystem().openbin(fp, mode="wb") as f:
-                pickle.dump(model, f)
+                cloudpickle.dump(model, f)
             metadata["checkpoint_path"] = fp
         return TrialReport(
             trial,
@@ -101,7 +101,7 @@ class SKCVObjective(SKObjective):
         self._cv = cv
 
     def run(self, trial: Trial) -> TrialReport:
-        params = dict(trial.params)
+        params = dict(trial.params.simple_value)
         if trial.trial_id != self._last_id:
             self._model_type = to_sk_model(params.pop(SPACE_MODEL_NAME))
             self._model_expr = to_sk_model_expr(self._model_type)
@@ -121,7 +121,7 @@ class SKCVObjective(SKObjective):
             model.fit(self._train_x, self._train_y)
             fp = os.path.join(self._checkpoint_path, str(uuid4()) + ".pkl")
             with FileSystem().openbin(fp, mode="wb") as f:
-                pickle.dump(model, f)
+                cloudpickle.dump(model, f)
             metadata["checkpoint_path"] = fp
         metric = float(np.mean(s))
         return TrialReport(
